--[[
	This module provides the rollout animation from
	a crawling position
	Usage:
		Bind the rollout.roll function to the jump key
]]
module("rollout",seeall)

local lara=item["lara"]

function roll()
	local st,stn=lara:getState()
	-- check the next state, for not triggering again
	if stn==80 then
		-- get Lara's floor position:
		-- (the underscore is a common placeholder for unrequired return values)
		local _,laraheight=lara:getPosition()

		-- check the floor height 220 units in front of Lara,
		-- to avoid a rollout if there's no room:
		local floorheight=getFloor(lara:getPosition(0,0,220))
		
		-- check if the floor is lower by at least 1 block height (1024),
		-- otherwise the rollout animation will look awkward:
		-- (421 is the rollout animation)
		if floorheight >= laraheight+1024 then
			lara:setAnim(421,0)	-- start the rollout anim

			-- setting the next animstate to 0 for the rollout
			-- avoids triggering it again if jump is pressed during the rollout:
			lara:setState(nil,0)

			--[[
			Animations do not reset the actionstate, (which may inhibit movement, or gun-usage)
			but may end up in another animstate with a usually different actionstate.
			Because of this, it may be necessary to reset the actionstate as well,
			depending on the target animstate.
			Rollout issue: When crawling, the actionstate is 1 (no fwd/back running, no gun usage)
				however, after the crawlspace rollout the animstate ends with animstate "falling",
				which usually works with actionstate 0 (so lara can draw weapons mid air).
				To fix this, the actionstate is reset to 0 when the rollout animation ends:
				(The actionstate _will_ be reset to 0 by the engine when Lara stands upright,
				 but not during the falling phase)
			]]
			startTimer(30,function()
				setActionState(0);		
			end)
			
		end		-- end of floorheight check
	end		-- end of animstate check
end
