--[[
	Example script
	Runs with the standard playable tutorial level (tut1.tr4)
]]

-- load some modules (from the modules directory):
require("status")
require("missile")
require("rollout")
require("breath")
require("test_textbox")

-- this is the same as item["lara"],
-- access other items by their index number,
-- i.e. itmSpikes=item[12] - (assuming that the spikes in that
-- level are item number 12)
lara=item.lara

-- --------------------------------

-- Show/hide the help text:
showHelp=false
function toggleHelp()
	if showHelp then
		textBoxOff(1)
		showHelp=false
	else
		-- show textbox centered on screen:
		textBox(1,500,120,
			"--T4Mod examle - Try these keys: --\n"
			.."\007h\001 - toggle this help\n"
			.."\007f\001 - fire missile\n"
			.."\007b\001 - toggle breath\n"
			.."\007z\001 - set teleport beacon\n"
			.."\007x\001 - teleport to beacon\n"
			.."\007i\001 - show Lara's anim status\n"
			.."\007crawl+jump\001 - rollout from ledge"
			,rgb(0,200,0,128)
			,"c")
		showHelp=true
	end
end


-- -----------------
-- Teleport marker:
-- It's always a good idea to group related functions
-- and variables in a do/end block (if you're not using a module),
-- this allows to use local variables which to not interfere
-- with other variables outside the block:
do
	local tele_x,tele_y,tele_z,tele_r=lara:getPosition()
	local color_tele=rgb(255,100,0)
	
	-- 0 is never a valid timer id, so it's safe to
	-- initialize the timer-id variable with 0 to
	-- indicate it has not yet been set:
	local tmr_tele=0

	-- draw a beacon marker:	
	function drawBeacon()
		for i=1,3 do
			particle.addShockwave(
				tele_x,tele_y-i*20,tele_z,
				400-i*100,
				500-i*100,
				color_tele,
				10,		-- duration
				5)		-- speed
		end
		playSfx(112,0,tele_x,tele_y,tele_z)
		return true		-- repeat the timer
	end

	-- Set the teleport beacon:	
	onKey("teleset",function()
		-- store current position:
		tele_x,tele_y,tele_z,tele_r=lara:getPosition()
		
		-- stop a previous marker-timer (using an unused timer-id
		-- will silently be ignored):
		stopTimer(tmr_tele)

		playSfx(215)
		drawBeacon()	-- draw a beacon instantly
		tmr_tele=startTimer(30,drawBeacon)	-- ... and again every second
	end)
	
	-- Teleport Lara to the beacon:
	onKey("telejump",function()
		-- only teleport if a beacon is set (hence, if the beacon timer is not 0):
		if tmr_tele ~= 0 then
			lara:moveTo(tele_x,tele_y,tele_z,tele_r,true)
			playSfx(108)			
			for i=0,2 do
				particle.addLightning(
					tele_x+math.random(-1000,1000), tele_y-1024, tele_z+math.random(-1000,1000),
					tele_x,tele_y,tele_z,
					color_tele,
					20,   -- lifetime
					100,  -- movement amplitude
					10,   -- beam width
					5)    -- beam segments
			end
		end	
	end)
end	-- end of the teleporter block

-- ---------------------------------------------
-- Bind all the keys to the respective funtions:

onKey("help",toggleHelp)

-- The crawlspace rollout:
-- This is bound to the jump-key (see t4mod.cfg):
onKey("rollout",rollout.roll)

onKey("stats",togglestats)

onKey("fire",missile.fire)

onKey("breath",breath.toggle)

onKey("t",test_textbox.toggle)


-- -------------------------
-- Show help on level start:
toggleHelp()


